@@ -61,6 +61,9 @@
 /* variables globales                                               */
 /*==================================================================*/
 
+/* typedef for the listbox callback functions */
+typedef char *(*my_getfuncptr)(int, int *);
+
 /*==================================================================*/
 /* variables statiques                                              */
 /*==================================================================*/
@@ -786,6 +789,402 @@ int my_edit_proc(int msg, DIALOG *d, int c)
    return D_O_K;
 }
 
+
+/* _handle_scrollable_click:
+ *  Helper to process a click on a scrollable object.
+ */
+void my_handle_scrollable_scroll_click(DIALOG *d, int listsize, int *offset, int height)
+{
+   int xx, yy;
+   int hh = d->h - 5;
+
+   while (gui_mouse_b()) {
+      int i = (hh * height + listsize/2) / listsize;
+      int len = (hh * (*offset) + listsize/2) / listsize + 2;
+
+      if ((gui_mouse_y() >= d->y+len) && (gui_mouse_y() <= d->y+len+i)) {
+	 xx = gui_mouse_y() - len + 2;
+	 while (gui_mouse_b()) {
+	    yy = (listsize * (gui_mouse_y() - xx) + hh/2) / hh;
+	    if (yy > listsize-height) 
+	       yy = listsize-height;
+
+	    if (yy < 0) 
+	       yy = 0;
+
+	    if (yy != *offset) {
+	       *offset = yy;
+	       scare_mouse();
+	       object_message(d, MSG_DRAW, 0);
+	       unscare_mouse();
+	    }
+
+	    /* let other objects continue to animate */
+	    broadcast_dialog_message(MSG_IDLE, 0);
+	 }
+      }
+      else {
+	 if (gui_mouse_y() <= d->y+len) 
+	    yy = *offset - height;
+	 else 
+	    yy = *offset + height;
+
+	 if (yy > listsize-height) 
+	    yy = listsize-height;
+
+	 if (yy < 0) 
+	    yy = 0;
+
+	 if (yy != *offset) {
+	    *offset = yy;
+	    scare_mouse();
+	    object_message(d, MSG_DRAW, 0);
+	    unscare_mouse();
+	 }
+      }
+
+      /* let other objects continue to animate */
+      broadcast_dialog_message(MSG_IDLE, 0);
+   }
+}
+
+
+
+/* _handle_scrollable_scroll:
+ *  Helper function to scroll through a scrollable object.
+ */
+void my_handle_scrollable_scroll(DIALOG *d, int listsize, int *index, int *offset)
+{
+   int height = (d->h-4) / text_height(font);
+
+   if (listsize <= 0) {
+      *index = *offset = 0;
+      return;
+   }
+
+   /* check selected item */
+   if (*index < 0) 
+      *index = 0;
+   else if (*index >= listsize)
+      *index = listsize - 1;
+
+   /* check scroll position */
+   while ((*offset > 0) && (*offset + height > listsize))
+      (*offset)--;
+
+   if (*offset >= *index) {
+      if (*index < 0) 
+	 *offset = 0;
+      else
+	 *offset = *index;
+   }
+   else {
+      while ((*offset + height - 1) < *index)
+	 (*offset)++;
+   }
+}
+
+
+
+/* idle_cb:
+ *  rest_callback() routine to keep dialogs animating nice and smoothly.
+ */
+static void my_idle_cb(void)
+{
+   broadcast_dialog_message(MSG_IDLE, 0);
+}
+
+
+
+/* _handle_listbox_click:
+ *  Helper to process a click on a listbox, doing hit-testing and moving
+ *  the selection.
+ */
+void my_handle_listbox_click(DIALOG *d)
+{
+   char *sel = d->dp2;
+   int listsize, height;
+   int i, j;
+
+   (*(my_getfuncptr)d->dp)(-1, &listsize);
+   if (!listsize)
+      return;
+
+   height = (d->h-4) / text_height(font);
+
+   i = MID(0, ((gui_mouse_y() - d->y - 2) / text_height(font)), 
+	      ((d->h-4) / text_height(font) - 1));
+   i += d->d2;
+   if (i < d->d2)
+      i = d->d2;
+   else {
+      if (i > d->d2 + height-1)
+	 i = d->d2 + height-1;
+      if (i >= listsize)
+	 i = listsize-1;
+   }
+
+   if (gui_mouse_y() <= d->y)
+      i = MAX(i-1, 0);
+   else if (gui_mouse_y() >= d->y+d->h-1)
+      i = MIN(i+1, listsize-1);
+
+   if (i != d->d1) {
+      if (sel) {
+	 if (key_shifts & (KB_SHIFT_FLAG | KB_CTRL_FLAG)) {
+	    if ((key_shifts & KB_SHIFT_FLAG) || (d->flags & D_INTERNAL)) {
+	       for (j=MIN(i, d->d1); j<=MAX(i, d->d1); j++)
+		  sel[j] = TRUE;
+	    }
+	    else
+	       sel[i] = !sel[i];
+	 }
+      }
+
+      d->d1 = i;
+      i = d->d2;
+      my_handle_scrollable_scroll(d, listsize, &d->d1, &d->d2);
+
+      d->flags |= D_DIRTY;
+
+      if (i != d->d2)
+	 rest_callback(MID(10, text_height(font)*16-d->h-1, 100), my_idle_cb);
+   }
+}
+
+
+
+/* draw_listbox:
+ *  Helper function to draw a listbox object.
+ */
+void my_draw_listbox(DIALOG *d)
+{
+   int height, listsize, i, len, bar, x, y, w;
+   int fg_color, fg, bg;
+   char *sel = d->dp2;
+   char s[1024];
+   int rtm;
+
+   (*(my_getfuncptr)d->dp)(-1, &listsize);
+   height = (d->h-4) / text_height(font);
+   bar = (listsize > height);
+   w = (bar ? d->w-15 : d->w-3);
+   fg_color = (d->flags & D_DISABLED) ? gui_mg_color : d->fg;
+
+   /* draw box contents */
+   for (i=0; i<height; i++) {
+      if (d->d2+i < listsize) {
+	 if (d->d2+i == d->d1) {
+	    fg = d->bg;
+	    bg = fg_color;
+	 } 
+	 else if ((sel) && (sel[d->d2+i])) { 
+	    fg = d->bg;
+	    bg = gui_mg_color;
+	 }
+	 else {
+	    fg = fg_color;
+	    bg = d->bg;
+	 }
+	 ustrzcpy(s, sizeof(s), (*(my_getfuncptr)d->dp)(i+d->d2, NULL));
+	 x = d->x + 2;
+	 y = d->y + 2 + i*text_height(font);
+	 rtm = text_mode(bg);
+	 rectfill(screen, x, y, x+7, y+text_height(font)-1, bg); 
+	 x += 8;
+	 len = ustrlen(s);
+	 while (text_length(font, s) >= MAX(d->w - 1 - (bar ? 22 : 10), 1)) {
+	    len--;
+	    usetat(s, len, 0);
+	 }
+	 textout(screen, font, s, x, y, -1);
+	 text_mode(rtm);
+	 x += text_length(font, s);
+	 if (x <= d->x+w) 
+	    rectfill(screen, x, y, d->x+w, y+text_height(font)-1, bg);
+      }
+      else {
+	 rectfill(screen, d->x+2,  d->y+2+i*text_height(font), 
+		  d->x+w, d->y+1+(i+1)*text_height(font), d->bg);
+      }
+   }
+
+   if (d->y+2+i*text_height(font) <= d->y+d->h-3)
+      rectfill(screen, d->x+2, d->y+2+i*text_height(font), 
+				       d->x+w, d->y+d->h-3, d->bg);
+
+   /* draw frame, maybe with scrollbar */
+   _draw_scrollable_frame(d, listsize, d->d2, height, fg_color, d->bg);
+}
+
+/* d_list_proc:
+ *  A list box object. The dp field points to a function which it will call
+ *  to obtain information about the list. This should follow the form:
+ *     const char *<list_func_name> (int index, int *list_size);
+ *  If index is zero or positive, the function should return a pointer to
+ *  the string which is to be displayed at position index in the list. If
+ *  index is  negative, it should return null and list_size should be set
+ *  to the number of items in the list. The list box object will allow the
+ *  user to scroll through the list and to select items list by clicking
+ *  on them, and if it has the input focus also by using the arrow keys. If 
+ *  the D_EXIT flag is set, double clicking on a list item will cause it to 
+ *  close the dialog. The index of the selected item is held in the d1 
+ *  field, and d2 is used to store how far it has scrolled through the list.
+ */
+int my_list_proc(int msg, DIALOG *d, int c)
+{
+   int listsize, i, bottom, height, bar, orig;
+   char *sel = d->dp2;
+   int redraw = FALSE;
+
+   switch (msg) {
+
+      case MSG_START:
+	 (*(my_getfuncptr)d->dp)(-1, &listsize);
+	 my_handle_scrollable_scroll(d, listsize, &d->d1, &d->d2);
+	 break;
+
+      case MSG_DRAW:
+	 my_draw_listbox(d);
+	 break;
+
+      case MSG_CLICK:
+	 (*(my_getfuncptr)d->dp)(-1, &listsize);
+	 height = (d->h-4) / text_height(font);
+	 bar = (listsize > height);
+	 if ((!bar) || (gui_mouse_x() < d->x+d->w-13)) {
+	    if ((sel) && (!(key_shifts & KB_CTRL_FLAG))) {
+	       for (i=0; i<listsize; i++) {
+		  if (sel[i]) {
+		     redraw = TRUE;
+		     sel[i] = FALSE;
+		  }
+	       }
+	       if (redraw) {
+		  scare_mouse();
+		  object_message(d, MSG_DRAW, 0);
+		  unscare_mouse();
+	       }
+	    }
+	    my_handle_listbox_click(d);
+	    while (gui_mouse_b()) {
+	       broadcast_dialog_message(MSG_IDLE, 0);
+	       d->flags |= D_INTERNAL;
+	       my_handle_listbox_click(d);
+	       d->flags &= ~D_INTERNAL;
+	    }
+	 }
+	 else {
+	    my_handle_scrollable_scroll_click(d, listsize, &d->d2, height);
+	 }
+	 break;
+
+      case MSG_DCLICK:
+	 (*(my_getfuncptr)d->dp)(-1, &listsize);
+	 height = (d->h-4) / text_height(font);
+	 bar = (listsize > height);
+	 if ((!bar) || (gui_mouse_x() < d->x+d->w-13)) {
+	    if (d->flags & D_EXIT) {
+	       if (listsize) {
+		  i = d->d1;
+		  object_message(d, MSG_CLICK, 0);
+		  if (i == d->d1) 
+		     return D_CLOSE;
+	       }
+	    }
+	 }
+	 break;
+
+      case MSG_WHEEL:
+	 (*(my_getfuncptr)d->dp)(-1, &listsize);
+	 height = (d->h-4) / text_height(font);
+	 if (height < listsize) {
+	    int delta = (height > 3) ? 3 : 1;
+	    if (c > 0) 
+	       i = MAX(0, d->d2-delta);
+	    else
+	       i = MIN(listsize-height, d->d2+delta);
+	    if (i != d->d2) {
+	       d->d2 = i;
+	       scare_mouse();
+	       object_message(d, MSG_DRAW, 0);
+	       unscare_mouse(); 
+	    }
+	 }
+	 break;
+
+      case MSG_KEY:
+	 (*(my_getfuncptr)d->dp)(-1, &listsize);
+	 if ((listsize) && (d->flags & D_EXIT))
+	    return D_CLOSE;
+	 break;
+
+      case MSG_WANTFOCUS:
+	 return D_WANTFOCUS;
+
+      case MSG_CHAR:
+	 (*(my_getfuncptr)d->dp)(-1, &listsize);
+
+	 if (listsize) {
+	    c >>= 8;
+
+	    bottom = d->d2 + (d->h-4)/text_height(font) - 1;
+	    if (bottom >= listsize-1)
+	       bottom = listsize-1;
+
+	    orig = d->d1;
+
+	    if (c == KEY_UP)
+	       d->d1--;
+	    else if (c == KEY_DOWN)
+	       d->d1++;
+	    else if (c == KEY_HOME)
+	       d->d1 = 0;
+	    else if (c == KEY_END)
+	       d->d1 = listsize-1;
+	    else if (c == KEY_PGUP) {
+	       if (d->d1 > d->d2)
+		  d->d1 = d->d2;
+	       else
+		  d->d1 -= (bottom - d->d2) ? bottom - d->d2 : 1;
+	    }
+	    else if (c == KEY_PGDN) {
+	       if (d->d1 < bottom)
+		  d->d1 = bottom;
+	       else
+		  d->d1 += (bottom - d->d2) ? bottom - d->d2 : 1;
+	    } 
+	    else 
+	       return D_O_K;
+
+	    if (sel) {
+	       if (!(key_shifts & (KB_SHIFT_FLAG | KB_CTRL_FLAG))) {
+		  for (i=0; i<listsize; i++)
+		     sel[i] = FALSE;
+	       }
+	       else if (key_shifts & KB_SHIFT_FLAG) {
+		  for (i=MIN(orig, d->d1); i<=MAX(orig, d->d1); i++) {
+		     if (key_shifts & KB_CTRL_FLAG)
+			sel[i] = (i != d->d1);
+		     else
+			sel[i] = TRUE;
+		  }
+	       }
+	    }
+
+	    /* if we changed something, better redraw... */ 
+	    my_handle_scrollable_scroll(d, listsize, &d->d1, &d->d2);
+	    d->flags |= D_DIRTY;
+	    return D_USED_CHAR;
+	 }
+	 break;
+   }
+
+   return D_O_K;
+}
+
+
+
 /*------------------------------------------------------------------*/
 BITMAP *my_create_bitmap (int w, int h)
 {
