@@ -58,6 +58,7 @@
 #include "disk.h"
 #include "palette.h"
 #include "viewport.h"
+#include "dialog.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -70,14 +71,16 @@
 /*------------------------------------------------------------------*/
 void display_a_back_image (BITMAP *bmp)
 {
- stretch_blit (bmp, screen, 0, 0, bmp->w, bmp->h,
-                            0, PAGE_FLIP_H, SCREEN_W, SCREEN_H);
+  scare_mouse();
+  stretch_blit (bmp, screen, 0, 0, bmp->w, bmp->h,
+		0, PAGE_FLIP_H, SCREEN_W, SCREEN_H);
+  unscare_mouse();
 }
 
 /*------------------------------------------------------------------*/
 void display_back_image (void)
 {
- display_a_back_image (BACK_IMAGE);
+  display_a_back_image (BACK_IMAGE);
 }
 
 
