@@ -94,21 +94,25 @@ extern int CONFIG_KEY_LEFT[NB_TEAMS];
 extern int CONFIG_KEY_DOWN[NB_TEAMS];
 extern int CONFIG_KEY_RIGHT[NB_TEAMS];
 extern int CONFIG_TEAM_COLOR[NB_TEAMS];
-extern int CONFIG_CPU_CONTROL[NB_TEAMS];
+extern int CONFIG_CONTROL_TYPE[NB_TEAMS];
+extern char CONFIG_PLAYER_NAME[NB_TEAMS][NAME_SIZE+1];
 extern int CONFIG_GAME_TIME;
 extern int CONFIG_INFO_BAR;
 extern int CONFIG_MOUSE_GAP;
 extern int CONFIG_JOYSTICK_ON;
 extern int CONFIG_CPU_ADVANTAGE;
 extern int CONFIG_PAGE_FLIP;
-extern int CONFIG_LANGAGE;
+extern int CONFIG_LANGUAGE;
 extern int CONFIG_WAVE_ON;
 extern int CONFIG_FRAMES_PER_SEC_LIMIT;
 extern int CONFIG_ROUNDS_PER_SEC_LIMIT;
-extern char CONFIG_NICKNAME[NICKNAME_SIZE+1];
 extern char CONFIG_SERVER_ADDRESS[SERVER_ADDRESS_SIZE+1];
 extern int CONFIG_SERVER_PORT;
 
+#define CONFIG_CONTROL_TYPE_OFF    0
+#define CONFIG_CONTROL_TYPE_HUMAN  1
+#define CONFIG_CONTROL_TYPE_CPU    2
+
 /*==================================================================*/
 /* constantes globales                                              */
 /*==================================================================*/
