@@ -52,9 +52,12 @@
 /* includes                                                         */
 /*==================================================================*/
 
+#include <string.h>
+
 #include "dialog.h"
 #include "sound.h"
 #include "back.h"
+#include "lang.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -67,22 +70,22 @@
 /*------------------------------------------------------------------*/
 int menu_real_x (int x)
 {
- return ((x*SCREEN_W)/MENU_VIRTUAL_W);
+  return ((x*SCREEN_W)/MENU_VIRTUAL_W);
 }
 
 /*------------------------------------------------------------------*/
 int menu_real_y (int y)
 {
- return ((y*SCREEN_H)/MENU_VIRTUAL_H);
+  return ((y*SCREEN_H)/MENU_VIRTUAL_H);
 }
 
 /*------------------------------------------------------------------*/
 void menu_real_coord (DIALOG *d)
 {
- d->x=menu_real_x (d->x);
- d->y=menu_real_y (d->y);
- d->w=menu_real_x (d->w);
- d->h=menu_real_y (d->h);
+  d->x=menu_real_x (d->x);
+  d->y=menu_real_y (d->y);
+  d->w=menu_real_x (d->w);
+  d->h=menu_real_y (d->h);
 }
 
 /*------------------------------------------------------------------*/
@@ -92,149 +95,169 @@ void menu_real_coord (DIALOG *d)
 /*------------------------------------------------------------------*/
 int find_center (int pos, int num, int space, int size)
 {
- int center;
+  int center;
 
- center=(size-num*space)/2;
- center+=pos*space+space/2;
+  center=(size-num*space)/2;
+  center+=pos*space+space/2;
 
- return center;
+  return center;
 }
 
 /*------------------------------------------------------------------*/
 void color_one_dialog (DIALOG *d)
 {
- d->fg=MENU_FG;
- d->bg=MENU_BG;
+  d->fg=MENU_FG;
+  d->bg=MENU_BG;
 }
 
 /*------------------------------------------------------------------*/
 void center_one_dialog (DIALOG *d,int x,int y,int w,int h)
 {
- d->x=x-w/2;
- d->y=y-h/2;
- d->w=w;
- d->h=h;
+  d->x=x-w/2;
+  d->y=y-h/2;
+  d->w=w;
+  d->h=h;
 }
 
 /*------------------------------------------------------------------*/
 void quick_buttons (DIALOG *d)
 {
- int i;
+  int i;
 
- d[MENU_QUICK_QUIT].dp="Quit";
- d[MENU_QUICK_BACK].dp="Back";
- d[MENU_QUICK_HELP].dp="Help";
- d[MENU_QUICK_MAIN].dp="Main";
- d[MENU_QUICK_QUIT].key='q';
- d[MENU_QUICK_BACK].key='b';
- d[MENU_QUICK_HELP].key='h';
- d[MENU_QUICK_MAIN].key='m';
+  d[MENU_QUICK_QUIT].dp=lw_lang_string(LW_LANG_STRING_DIALOG_QUIT);
+  d[MENU_QUICK_BACK].dp=lw_lang_string(LW_LANG_STRING_DIALOG_BACK);
+  d[MENU_QUICK_PLAY].dp=lw_lang_string(LW_LANG_STRING_DIALOG_PLAY);
+  d[MENU_QUICK_MAIN].dp=lw_lang_string(LW_LANG_STRING_DIALOG_MAIN);
+  d[MENU_QUICK_QUIT].key='q';
+  d[MENU_QUICK_BACK].key='b';
+  d[MENU_QUICK_PLAY].key='h';
+  d[MENU_QUICK_MAIN].key='m';
 
- d[MENU_QUICK_BACK].x=
- d[MENU_QUICK_QUIT].x= MENU_W_SPACE/2;
- d[MENU_QUICK_HELP].x=
- d[MENU_QUICK_MAIN].x= MENU_VIRTUAL_W-1
-                       -MENU_W_SPACE/2
-                       -MENU_W_QUICK;
- d[MENU_QUICK_BACK].y=
- d[MENU_QUICK_HELP].y= MENU_H_SPACE/2;
- d[MENU_QUICK_QUIT].y=
- d[MENU_QUICK_MAIN].y= MENU_VIRTUAL_H-1
-                       -MENU_H_SPACE/2
-                       -MENU_H_QUICK;
- for (i=0; i<4; ++i)
+  d[MENU_QUICK_BACK].x=
+    d[MENU_QUICK_QUIT].x= MENU_W_SPACE/2;
+  d[MENU_QUICK_PLAY].x=
+    d[MENU_QUICK_MAIN].x= MENU_VIRTUAL_W-1
+    -MENU_W_SPACE/2
+    -MENU_W_QUICK;
+  d[MENU_QUICK_BACK].y=
+    d[MENU_QUICK_PLAY].y= MENU_H_SPACE/2;
+  d[MENU_QUICK_QUIT].y=
+    d[MENU_QUICK_MAIN].y= MENU_VIRTUAL_H-1
+    -MENU_H_SPACE/2
+    -MENU_H_QUICK;
+  for (i=0; i<4; ++i)
     {
-     d[i].proc=my_button_proc;
-     d[i].flags=D_EXIT;
-     d[i].h=MENU_H_QUICK;
-     d[i].w=MENU_W_QUICK;
-     color_one_dialog (d+i);
-     menu_real_coord (d+i);
+      d[i].proc=my_button_proc;
+      d[i].flags=D_EXIT;
+      d[i].h=MENU_H_QUICK;
+      d[i].w=MENU_W_QUICK;
+      color_one_dialog (d+i);
+      menu_real_coord (d+i);
     }
 }
 
 /*------------------------------------------------------------------*/
 void standard_button (DIALOG *d, int x_pos, int y_pos,
-                                        int x_num, int y_num)
+		      int x_num, int y_num)
 {
- d->proc=my_button_proc;
+  d->proc=my_button_proc;
 
- center_one_dialog (d,
-                    find_center (x_pos, x_num,
-                      MENU_W_STANDARD+MENU_W_SPACE, MENU_VIRTUAL_W),
-                    find_center (y_pos, y_num,
-                      MENU_H_STANDARD+MENU_H_SPACE, MENU_VIRTUAL_H),
-                    MENU_W_STANDARD,
-                    MENU_H_STANDARD);
- color_one_dialog (d);
- menu_real_coord (d);
- d->key=0;
- d->dp="";
- d->flags=D_EXIT;
+  center_one_dialog (d,
+		     find_center (x_pos, x_num,
+				  MENU_W_STANDARD+MENU_W_SPACE, MENU_VIRTUAL_W),
+		     find_center (y_pos, y_num,
+				  MENU_H_STANDARD+MENU_H_SPACE, MENU_VIRTUAL_H),
+		     MENU_W_STANDARD,
+		     MENU_H_STANDARD);
+  color_one_dialog (d);
+  menu_real_coord (d);
+  d->key=0;
+  d->dp="";
+  d->flags=D_EXIT;
 }
 
 /*------------------------------------------------------------------*/
 void standard_small_button (DIALOG *d, int x_pos, int y_pos,
-                                       int x_num, int y_num)
+			    int x_num, int y_num)
 {
- d->proc=my_button_proc;
+  d->proc=my_button_proc;
 
- center_one_dialog (d,
-                    find_center (x_pos, x_num,
-                      MENU_W_STANDARD/2+MENU_W_SPACE, MENU_VIRTUAL_W),
-                    find_center (y_pos, y_num,
-                      MENU_H_STANDARD+MENU_H_SPACE, MENU_VIRTUAL_H),
-                    MENU_W_STANDARD/2,
-                    MENU_H_STANDARD);
- color_one_dialog (d);
- menu_real_coord (d);
- d->key=0;
- d->dp="";
- d->flags=D_EXIT;
+  center_one_dialog (d,
+		     find_center (x_pos, x_num,
+				  MENU_W_STANDARD/2+MENU_W_SPACE, MENU_VIRTUAL_W),
+		     find_center (y_pos, y_num,
+				  MENU_H_STANDARD+MENU_H_SPACE, MENU_VIRTUAL_H),
+		     MENU_W_STANDARD/2,
+		     MENU_H_STANDARD);
+  color_one_dialog (d);
+  menu_real_coord (d);
+  d->key=0;
+  d->dp="";
+  d->flags=D_EXIT;
+}
+
+/*------------------------------------------------------------------*/
+void standard_big_button (DIALOG *d, int x_pos, int y_pos,
+			  int x_num, int y_num)
+{
+  d->proc=my_button_proc;
+
+  center_one_dialog (d,
+		     find_center (x_pos, x_num,
+				  MENU_W_STANDARD*2+MENU_W_SPACE, MENU_VIRTUAL_W),
+		     find_center (y_pos, y_num,
+				  MENU_H_STANDARD+MENU_H_SPACE, MENU_VIRTUAL_H),
+		     MENU_W_STANDARD*2,
+		     MENU_H_STANDARD);
+  color_one_dialog (d);
+  menu_real_coord (d);
+  d->key=0;
+  d->dp="";
+  d->flags=D_EXIT;
 }
 
 /*------------------------------------------------------------------*/
 void main_message (DIALOG *d, char *str)
 {
- standard_button (d,0,0,1,1);
+  standard_button (d,0,0,1,1);
 
- d->dp=str;
- d->key=0;
- d->proc=my_textbox_proc;
- d->flags=0;
+  d->dp=str;
+  d->key=0;
+  d->proc=my_textbox_proc;
+  d->flags=0;
 }
 
 /*------------------------------------------------------------------*/
 void main_info (DIALOG *d, char *str)
 {
- color_one_dialog (d);
- d->proc=my_textbox_proc;
- d->dp=str;
- d->key=0;
- d->flags=0;
+  color_one_dialog (d);
+  d->proc=my_textbox_proc;
+  d->dp=str;
+  d->key=0;
+  d->flags=0;
 }
 
 /*------------------------------------------------------------------*/
 int my_do_dialog_no_clear (DIALOG *d, int f)
- {
+{
   int result;
 
   result=do_dialog (d,f);
   play_click();
 
   return result;
- }
+}
 
 /*------------------------------------------------------------------*/
 int my_do_dialog (DIALOG *d, int f)
- {
+{
   int result;
 
   display_back_image ();
   result=my_do_dialog_no_clear (d,f);
 
   return result;
- }
+}
 
 /*------------------------------------------------------------------*/
 void display_center_message (char *str)
@@ -242,6 +265,8 @@ void display_center_message (char *str)
   DIALOG d[2];
   DIALOG_PLAYER *dp;
 
+  memset(d,0,sizeof(d));
+
   display_back_image ();
   main_message (d,str);
   d[1].proc=0;
@@ -249,23 +274,23 @@ void display_center_message (char *str)
   update_dialog (dp);
   shutdown_dialog (dp);
 
-   /*
-    * We wait a little bit, so that the player can see the message
-    */
+  /*
+   * We wait a little bit, so that the player can see the message
+   */
   //rest(100);
 }
 
 /*------------------------------------------------------------------*/
 int slider_int (void *dp3, int d2)
 {
- int *val;
+  int *val;
 
- val=dp3;
- *val=d2;
+  val=dp3;
+  *val=d2;
 
- play_click ();
+  play_click ();
 
- return 0;
+  return 0;
 }
 
 
