@@ -70,27 +70,7 @@
 #define RAW_TEXTURE_DAT_NUMBER  512
 
 #define MIDI_MUSIC_MAX_NUMBER   256
-#define MIDI_MUSIC_DAT_NUMBER     3
-
-#define LANGAGE_NUMBER      2
-#define HELP_TEXT_NUMBER    13
-
-/*
- * these constants must be in alphabetical order
- */
-#define HELP_TEXT_ABOUT     0
-#define HELP_TEXT_ADVANCED  1
-#define HELP_TEXT_GRAPHICS  2
-#define HELP_TEXT_MAIN      3
-#define HELP_TEXT_MAP       4
-#define HELP_TEXT_NETGAME   5
-#define HELP_TEXT_OPTIONS   6
-#define HELP_TEXT_RULES     7
-#define HELP_TEXT_SCORE     8
-#define HELP_TEXT_SOUND     9
-#define HELP_TEXT_SPEEDS    10
-#define HELP_TEXT_TEAMS     11
-#define HELP_TEXT_WAVE      12
+#define MIDI_MUSIC_DAT_NUMBER     7
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -123,8 +103,7 @@ extern FONT *BIG_FONT;
 extern FONT *SMALL_FONT;
 extern BITMAP *BIG_MOUSE_CURSOR;
 extern BITMAP *SMALL_MOUSE_CURSOR;
-
-extern char *HELP_TEXT[LANGAGE_NUMBER][HELP_TEXT_NUMBER];
+extern BITMAP *INVISIBLE_MOUSE_CURSOR;
 
 /*==================================================================*/
 /* fonctions globales                                               */
