@@ -52,6 +52,8 @@
 /* includes                                                         */
 /*==================================================================*/
 
+#include <string.h>
+
 #include "back.h"
 #include "config.h"
 #include "dialog.h"
@@ -68,69 +70,58 @@
 /*==================================================================*/
 
 /*------------------------------------------------------------------*/
-static char *get_langage_bar_label()
+void prepare_help (DIALOG d[6], char *str)
 {
- if (!CONFIG_LANGAGE)
-    return("->fr");
- else
-     return("->en");
-}
- 
-/*------------------------------------------------------------------*/
-void prepare_help (DIALOG d[6], int i)
-{
- quick_buttons (d);
+  quick_buttons (d);
 
- color_one_dialog (d+4);
- d[4].proc=my_textbox_proc;
- d[4].d2=0;
- d[MENU_QUICK_HELP].dp=get_langage_bar_label();
- d[4].dp=HELP_TEXT[CONFIG_LANGAGE][i];
- d[4].key=0;
- d[4].flags=0;
- d[4].x=(MENU_W_SPACE*3)/2+MENU_W_QUICK;
- d[4].y=(MENU_H_SPACE*3)/2+MENU_H_QUICK;
- d[4].w=MENU_VIRTUAL_W-MENU_W_SPACE*3-MENU_W_QUICK*2;
- d[4].h=MENU_VIRTUAL_H-MENU_H_SPACE*3-MENU_H_QUICK*2;
- menu_real_coord (d+4);
+  color_one_dialog (d+4);
+  d[4].proc=my_textbox_proc;
+  d[4].d2=0;
+  d[4].dp=str;
+  d[4].key=0;
+  d[4].flags=0;
+  d[4].x=(MENU_W_SPACE*3)/2+MENU_W_QUICK;
+  d[4].y=(MENU_H_SPACE*3)/2+MENU_H_QUICK;
+  d[4].w=MENU_VIRTUAL_W-MENU_W_SPACE*3-MENU_W_QUICK*2;
+  d[4].h=MENU_VIRTUAL_H-MENU_H_SPACE*3-MENU_H_QUICK*2;
+  menu_real_coord (d+4);
 
- d[5].proc=NULL;
+  d[5].proc=NULL;
 }
 
 /*------------------------------------------------------------------*/
-int display_help (int i)
+int display_help (char *str)
 {
-   int retour=0,choix=MENU_QUICK_BACK;
-   DIALOG d[6];
+  int retour=0,choix=MENU_QUICK_BACK;
+  DIALOG d[6];
 
-   prepare_help (d,i);
-   display_back_image();
+  memset(d,0,sizeof(d));
+
+  prepare_help (d,str);
+
+  display_back_image();
  
-   while (retour==0)
-         {
-          choix=my_do_dialog_no_clear (d,choix);
-          switch (choix)
-            {
-             case -1:
-             case MENU_QUICK_BACK:
-                  retour=1;
-                  break;
-             case MENU_QUICK_HELP:
-                  CONFIG_LANGAGE=CONFIG_LANGAGE ? 0 : 1;
-                  d[MENU_QUICK_HELP].dp=get_langage_bar_label();
-                  d[4].dp=HELP_TEXT[CONFIG_LANGAGE][i];
-                  my_button_proc (MSG_DRAW, d+MENU_QUICK_HELP, 0);
-                  my_textbox_proc (MSG_DRAW, d+4, 0);
-                  break;
-             case MENU_QUICK_MAIN:
-                  retour=MENU_TOP;
-                  break;
-             case MENU_QUICK_QUIT:
-                  if (confirm_quit())
-                    retour=MENU_EXIT;
-                  break;
-            }
-          }
+  while (retour==0)
+    {
+      choix=my_do_dialog_no_clear (d,choix);
+      switch (choix)
+	{
+	case -1:
+	case MENU_QUICK_BACK:
+	  retour=1;
+	  break;
+	case MENU_QUICK_PLAY:
+	  retour=MENU_PLAY;
+	  break;
+	case MENU_QUICK_MAIN:
+	  retour=MENU_TOP;
+	  break;
+	case MENU_QUICK_QUIT:
+	  if (confirm_quit())
+	    retour=MENU_EXIT;
+	  break;
+	}
+    }
   if (retour>0)
     retour--;
   return retour;
