@@ -63,7 +63,7 @@
 /* fonctions globales                                               */
 /*==================================================================*/
 
-void prepare_help (DIALOG d[6], int i);
-int display_help (int i);
+void prepare_help (DIALOG d[6], char *str);
+int display_help (char *str);
 
 #endif
