@@ -118,6 +118,8 @@ int init_all ()
 
   lw_lang_init();
 
+  set_uformat(U_ASCII);
+
   allegro_init ();
 #ifdef ALLEGRO_DOS
   set_gfx_mode (GFX_TEXT, 0, 0, 0, 0);
@@ -127,7 +129,10 @@ int init_all ()
   log_print_str("Allegro ID : ");
   log_println_str(allegro_id);
   log_println();
- 
+
+  set_color_depth(8);
+  set_color_conversion(COLORCONV_REDUCE_TO_256);
+
   log_print_str("Loading config options from \"");
   log_print_str(STARTUP_CFG_PATH);
   log_print_str("\"");
@@ -183,7 +188,7 @@ int init_all ()
   log_print_str("Setting up network");
   display_success(network=lw_sock_init());
 
-  set_color_conversion (COLORCONV_TOTAL);
+  /*  set_color_conversion (COLORCONV_TOTAL); */
   
   result= timer&&keyboard&&mouse
     &&(sound||!STARTUP_CHECK)
