@@ -66,9 +66,9 @@ typedef struct
   int active;
   int network;
   int server_id;
-  char nickname[NICKNAME_SIZE];
   int color;
   int part;
+  char name[NAME_SIZE+1];
 } LW_WHO;
 
 /*==================================================================*/
