@@ -52,6 +52,8 @@
 /* includes                                                         */
 /*==================================================================*/
 
+#include <string.h>
+
 #include "back.h"
 #include "base.h"
 #include "config.h"
@@ -66,6 +68,9 @@
 #include "rules.h"
 #include "volume.h"
 #include "speeds.h"
+#include "language.h"
+#include "controls.h"
+#include "lang.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -78,66 +83,75 @@
 /*------------------------------------------------------------------*/
 int options (void)
 {
- DIALOG d[10];
+  DIALOG d[12];
   int i,choix=4,retour=0;
 
+  memset(d,0,sizeof(d));
+
   while (retour==0)
-         {
-          for (i=0; i<4; ++i)
-              standard_button (d+i+4,0,i,1,6);
-          standard_button (d+8,0,5,1,6);
+    {
+      for (i=0; i<6; ++i)
+	standard_button (d+i+4,0,i,1,8);
+      standard_button (d+10,0,7,1,8);
 
-          quick_buttons(d);
-          d[4].dp="Graphics";
-          d[5].dp="Sound";
-          d[6].dp="Rules";
-	  d[7].dp="Speeds";
-          d[8].dp="Default";
-          d[9].proc=0;
+      quick_buttons(d);
+      d[4].dp=lw_lang_string(LW_LANG_STRING_OPTIONS_GRAPHICS);
+      d[5].dp=lw_lang_string(LW_LANG_STRING_OPTIONS_SOUND);
+      d[6].dp=lw_lang_string(LW_LANG_STRING_OPTIONS_RULES);
+      d[7].dp=lw_lang_string(LW_LANG_STRING_OPTIONS_SPEEDS);
+      d[8].dp=lw_lang_string(LW_LANG_STRING_OPTIONS_CONTROLS);
+      d[9].dp=lw_lang_string(LW_LANG_STRING_OPTIONS_LANGUAGE);
+      d[10].dp=lw_lang_string(LW_LANG_STRING_OPTIONS_DEFAULT);
+      d[11].proc=0;
 
-          choix=my_do_dialog (d,choix);
-          switch (choix)
-            {
-             case -1:
-             case MENU_QUICK_BACK:
-                  retour=1;
-                  break;
-             case MENU_QUICK_MAIN:
-                  retour=MENU_TOP;
-                  break;
-             case MENU_QUICK_QUIT:
-                  if (confirm_quit())
-                    retour=MENU_EXIT;
-                  else
-                    display_back_image();
-                  break;
-             case MENU_QUICK_HELP:
-                  retour=display_help (HELP_TEXT_OPTIONS);
-                  display_back_image ();
-                  break;
-             case 4:
-                  retour=graphic_options ();
-                  break;
-             case 5:
-                  retour=sound_options ();
-                  break;
-             case 6:
-                  retour=rules_options ();
-                  break;
-             case 7:
-                  retour=speeds_options ();
-                  break;
-             case 8:
-		  load_default_options ();
-                  retour=0;
-                  break;
-            }
-        }
+      choix=my_do_dialog (d,choix);
+      switch (choix)
+	{
+	case -1:
+	case MENU_QUICK_BACK:
+	  retour=1;
+	  break;
+	case MENU_QUICK_MAIN:
+	  retour=MENU_TOP;
+	  break;
+	case MENU_QUICK_QUIT:
+	  if (confirm_quit())
+	    retour=MENU_EXIT;
+	  else
+	    display_back_image();
+	  break;
+	case MENU_QUICK_PLAY:
+	  retour=MENU_PLAY;
+	  break;
+	case 4:
+	  retour=graphic_options ();
+	  break;
+	case 5:
+	  retour=sound_options ();
+	  break;
+	case 6:
+	  retour=rules_options ();
+	  break;
+	case 7:
+	  retour=speeds_options ();
+	  break;
+	case 8:
+	  retour=controls_options ();
+	  break;
+	case 9:
+	  retour=language_options ();
+	  break;
+	case 10:
+	  load_default_options ();
+	  retour=0;
+	  break;
+	}
+    }
 
   if (retour>0)
     retour--;
 
   return retour;
- }
+}
 
 
