@@ -73,88 +73,96 @@ static char *ARGUMENT_VALUE [MAX_ARGUMENT_NUMBER];
 /*------------------------------------------------------------------*/
 static int is_arg_marker (char c)
 {
- return (c=='/' || c=='-');
+#ifdef UNIX
+  /*
+   * Under Unix, we do not accept / as an option key,
+   * since it is used for paths
+   */
+  return (c=='-');
+#else
+  return (c=='/' || c=='-');
+#endif
 }
 
 /*------------------------------------------------------------------*/
 void read_command_line (int argc, char **argv)
 {
- int i,j;
- char *str;
+  int i,j;
+  char *str;
 
- for (i=0;i<MAX_ARGUMENT_NUMBER;++i)
-     ARGUMENT_NAME[i]=ARGUMENT_VALUE[i]="";
+  for (i=0;i<MAX_ARGUMENT_NUMBER;++i)
+    ARGUMENT_NAME[i]=ARGUMENT_VALUE[i]="";
 
- str=EXECUTABLE_NAME=argv[0];
- while (*str)
-       {
-        if ((*str)=='/' || (*str)=='\\')
-           EXECUTABLE_NAME=(str+1);
-        str++;
-       }
+  str=EXECUTABLE_NAME=argv[0];
+  while (*str)
+    {
+      if ((*str)=='/' || (*str)=='\\')
+	EXECUTABLE_NAME=(str+1);
+      str++;
+    }
 
- for (i=1,j=0;i<argc && j<MAX_ARGUMENT_NUMBER;++i)
-     {
+  for (i=1,j=0;i<argc && j<MAX_ARGUMENT_NUMBER;++i)
+    {
       str=argv[i];
       if (is_arg_marker(str[0]))
-         {
+	{
           ARGUMENT_NAME [j]=str+1;
           if (i<argc-1)
-             {
+	    {
               str=argv[i+1];
               if (!is_arg_marker(str[0]))
-                 {
+		{
                   ARGUMENT_VALUE[j]=str;
                   i++;
-                 }
-             }
+		}
+	    }
           j++;
-         }
-     }
+	}
+    }
 }
 
 /*------------------------------------------------------------------*/
 int exist_argument (char *str)
 {
- int i,found=0;
+  int i,found=0;
 
- for (i=0;i<MAX_ARGUMENT_NUMBER && !found;++i)
-     found=!strcmp (str,ARGUMENT_NAME[i]);
+  for (i=0;i<MAX_ARGUMENT_NUMBER && !found;++i)
+    found=!strcmp (str,ARGUMENT_NAME[i]);
 
- return found;
+  return found;
 }
 
 /*------------------------------------------------------------------*/
 int exist_argument_value (char *str)
 {
- int i,found=0;
+  int i,found=0;
 
- for (i=0;i<MAX_ARGUMENT_NUMBER && !found;++i)
-     found= (!strcmp (str,ARGUMENT_NAME[i]))
-              && (strcmp ("",ARGUMENT_VALUE[i]));
+  for (i=0;i<MAX_ARGUMENT_NUMBER && !found;++i)
+    found= (!strcmp (str,ARGUMENT_NAME[i]))
+      && (strcmp ("",ARGUMENT_VALUE[i]));
 
- return found;
+  return found;
 }
 
 /*------------------------------------------------------------------*/
 char *get_argument_str (char *str)
 {
- int i,place=0,found=0;
+  int i,place=0,found=0;
 
- for (i=0;i<MAX_ARGUMENT_NUMBER && !found;++i)
-     if ((found=(!strcmp (str,ARGUMENT_NAME[i])))!=0)
-        place=i;
+  for (i=0;i<MAX_ARGUMENT_NUMBER && !found;++i)
+    if ((found=(!strcmp (str,ARGUMENT_NAME[i])))!=0)
+      place=i;
 
- if (found)
+  if (found)
     return ARGUMENT_VALUE[place];
- else
-     return "";
+  else
+    return "";
 }
 
 /*------------------------------------------------------------------*/
 int get_argument_int (char *str)
 {
- return (atoi (get_argument_str(str)));
+  return (atoi (get_argument_str(str)));
 }
 
 
