@@ -52,6 +52,7 @@
 /* includes                                                         */
 /*==================================================================*/
 
+#include <string.h>
 #include <allegro.h>
 
 #include "back.h"
@@ -68,6 +69,8 @@
 #include "sock2gen.h"
 #include "keyexch.h"
 #include "music.h"
+#include "lang.h"
+#include "mouse.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -90,6 +93,8 @@ int play_sequence (void)
   DIALOG d[2];
   DIALOG_PLAYER *dp;
 
+  memset(d,0,sizeof(d));
+
   d[1].proc=0;
 
   /*
@@ -100,7 +105,7 @@ int play_sequence (void)
    * we display a "Get ready!" message so that the user does not worry
    * about what's going on
    */
-  main_message (d,"Get ready!");
+  main_message (d,lw_lang_string(LW_LANG_STRING_PLAY_GETREADY));
   /*
    * we call update dialog artificially so that the "Get ready"
    * message is actually blitted on the screen
@@ -160,6 +165,8 @@ int play_sequence (void)
 				CONFIG_PAGE_FLIP,
 				CONFIG_FULLSCREEN);
 
+     lw_mouse_hide();
+
      /*
       * the blank round function initializes the double-buffer system
       * and the main display target, it might fail because of lacking memory
@@ -195,7 +202,7 @@ int play_sequence (void)
      /*
       * we close the network socket abruptly
       */
-     lw_sock_close(LW_KEYEXCH_SOCK);
+     lw_sock_close(&LW_KEYEXCH_SOCK);
 
      /*
       * we turn the volume down
@@ -212,6 +219,8 @@ int play_sequence (void)
      if (need_to_change_mode(CONFIG_GFX_GAME,CONFIG_GFX_MENU,CONFIG_PAGE_FLIP))
 		result=set_resolution (CONFIG_GFX_MENU,0,CONFIG_FULLSCREEN);
 
+     lw_mouse_show();
+
      /*
       * displays the 3 tubes with the score
       */
@@ -229,7 +238,7 @@ int play_sequence (void)
      /*
       * we close the network socket abruptly
       */
-     lw_sock_close(LW_KEYEXCH_SOCK);
+     lw_sock_close(&LW_KEYEXCH_SOCK);
 
      error_not_enough_big_data ();
     }
