@@ -60,6 +60,7 @@
 /*==================================================================*/
 
 #include "network.h"
+#include "startinf.h"
 
 /*==================================================================*/
 /* fonctions globales                                               */
@@ -68,9 +69,8 @@
 int lw_protocol_do_ping (int sock);
 int lw_protocol_tell_version (int sock, char *version);
 int lw_protocol_tell_program (int sock, char *program);
-int lw_protocol_tell_nickname (int sock, char *nickname);
 int lw_protocol_ask_free_teams (int sock, int *nb);
-int lw_protocol_reserve_team (int sock, int num);
+int lw_protocol_reserve_team (int sock, int num, char *name);
 int lw_protocol_ask_who (int sock, 
 			 int num,
 			 LW_WHO *who);
@@ -79,5 +79,10 @@ int lw_protocol_recv_map (int sock, void **map);
 int lw_protocol_send_config (int sock);
 int lw_protocol_recv_config (int sock);
 int lw_protocol_i_am_ready (int sock); 
+int lw_protocol_waiting (int sock, int *waited_teams); 
+int lw_protocol_force_start (int sock); 
+int lw_protocol_next (int sock); 
+int lw_protocol_ask_teamstartinfo(int sock, int team,
+				  LW_TEAMSTARTINFO *team_start_info); 
 
 #endif
