@@ -60,6 +60,8 @@
 #include "srvteam.h"
 #include "netkey.h"
 #include "netconf.h"
+#include "startinf.h"
+#include "netmess.h"
 
 /*==================================================================*/
 /* structs                                                          */
@@ -72,10 +74,10 @@ typedef struct
   int port;
   int program_ok;
   int version_ok;
-  int nickname_ok;
   int ready_ok;
-  char nickname[NICKNAME_SIZE+1];
   int nb_local_teams;
+  int start;
+  void *map;
   LW_SRVTEAM team[NB_TEAMS];
 } LW_SRVCHAN;
 
@@ -85,6 +87,8 @@ typedef struct
 
 int lw_srvchan_wait_teams(LW_SRVCHAN *chan, int *free_teams,
 			  int sock, void **map,LW_NETCONF *config);
+int lw_srvchan_keepalive(LW_SRVCHAN *chan, int waited_teams,
+			 LW_TEAMSTARTINFO *team_start_info);
 int lw_srvchan_tell_who(LW_SRVCHAN *chan,void *map,LW_NETCONF *config);
 int lw_srvchan_final_ok(LW_SRVCHAN *chan);
 int lw_srvchan_find_team_by_server_id(LW_SRVCHAN *chan,int server_id);
@@ -93,6 +97,16 @@ void lw_srvchan_close(LW_SRVCHAN *chan);
 int lw_srvchan_recv_keys(LW_SRVCHAN *chan, LW_NETKEY *netkey);
 int lw_srvchan_send_keys(LW_SRVCHAN *chan, LW_NETKEY *netkey);
 
+int lw_srvchan_handle_ping(int sock, LW_NETMESS *mess);
+int lw_srvchan_handle_echo(int sock, LW_NETMESS *mess);
+int lw_srvchan_handle_program(int sock, LW_NETMESS *mess, 
+			      int *ok);
+int lw_srvchan_handle_version(int sock, LW_NETMESS *mess, 
+			      int *ok);
+int lw_srvchan_handle_free(int sock, LW_NETMESS *mess, 
+			   int free_teams, int *ok);
+int lw_srvchan_handle_unknown(int sock, LW_NETMESS *mess);
+
 #endif
 
 
