@@ -467,23 +467,47 @@ int lw_srvcont_wait_teams(LW_SRVCONT *cont,
  */
 int lw_srvcont_tell_who(LW_SRVCONT *cont)
 {
-  int i;
+  int i,j;
   int result=0;
 
   if (distribute_teams(cont))
     {
       result=1;
-      for (i=0;i<cont->nb_chans;++i)
+      for (i=cont->nb_chans-1;i>=0;--i)
 	{
 	  if (!lw_srvchan_tell_who(&(cont->chan[i]),
 				   cont->chan[0].map,
 				   &(cont->config)))
 	    {
-	      result=0;
+	      /*
+	       * There's been an error exchanging data with this team
+	       * so we decide to "close" it.
+	       */
+	      log_print_str("Disconnecting \"");
+	      log_print_str(cont->chan[i].ip);
+	      log_print_str(":");
+	      log_print_int(cont->chan[i].port);
+	      log_print_str("\"");
+	      log_println();
+
+	      lw_srvchan_close(&(cont->chan[i]));
+	      for (j=i+1;j<cont->nb_chans;++j)
+		{
+		  cont->chan[j-1]=cont->chan[j];
+		}
+	      cont->nb_chans--;
 	    }
 	}
     }
 
+  /*
+   * We start the game only if there are more than 1 channels opened...
+   */
+  if (cont->nb_chans>0)
+    {
+      result=1;
+    }
+
   return result;
 }
 
@@ -603,7 +627,7 @@ int lw_srvcont_replicate_keys(LW_SRVCONT *cont,
 	  /*
 	   * First we get the informations from all the players
 	   */
-	  for (i=0;i<cont->nb_chans;++i)
+	  for (i=cont->nb_chans-1;i>=0;--i)
 	    {
 	      if (lw_srvchan_recv_keys(&(cont->chan[i]),&netkey))
 		{
@@ -713,7 +737,7 @@ int lw_srvcont_replicate_keys(LW_SRVCONT *cont,
 	      /*
 	       * Now we send the information to all the players
 	       */
-	      for (i=0;i<cont->nb_chans;++i)
+	      for (i=cont->nb_chans-1;i>=0;--i)
 		{
 		  if (!lw_srvchan_send_keys(&(cont->chan[i]),&netkey))
 		    {
