@@ -52,6 +52,7 @@
 /* includes                                                         */
 /*==================================================================*/
 
+
 #include "srvteam.h"
 
 /*==================================================================*/
@@ -66,7 +67,7 @@ void lw_srvteam_reset(LW_SRVTEAM *team)
 {
   team->active=0;
   team->network=0;
-  team->nickname[0]='\0';
   team->server_id=0;
+  team->name[0]='\0';
 }
 
