@@ -65,8 +65,8 @@ typedef struct
 {
   int active;
   int network;
-  char nickname[NICKNAME_SIZE+1];
   int server_id;
+  char name[NAME_SIZE+1];
 } LW_SRVTEAM;
 
 /*==================================================================*/
