@@ -52,6 +52,8 @@
 /* includes                                                         */
 /*==================================================================*/
 
+#include <string.h>
+
 #include "back.h"
 #include "config.h"
 #include "dialog.h"
@@ -60,6 +62,7 @@
 #include "menu.h"
 #include "sound.h"
 #include "volume.h"
+#include "lang.h"
 
 /*==================================================================*/
 /* variables globales                                               */
@@ -77,71 +80,72 @@ int sound_options (void)
   int i,choix=4,retour=0;
   static int y_pos[5]={0,2,4,5,7};
 
+  memset(d,0,sizeof(d));
+
   for (i=0; i<5; ++i)
-      {
-       standard_button (d+i+4,0,y_pos[i],2,8);
-       d[i+4].proc=my_textbox_proc;
-      }
+    {
+      standard_button (d+i+4,0,y_pos[i],2,8);
+      d[i+4].proc=my_textbox_proc;
+    }
   for (i=0; i<5; ++i)
-      {
-       standard_button (d+i+9,1,y_pos[i],2,8);
-       d[i+9].proc=my_slider_proc;
-      }
+    {
+      standard_button (d+i+9,1,y_pos[i],2,8);
+      d[i+9].proc=my_slider_proc;
+    }
 
   quick_buttons(d);
 
-  d[4].dp="Sfx";
-  d[5].dp="Click";
-  d[6].dp="Game water";
-  d[7].dp="Menu water";
-  d[8].dp="Music";
+  d[4].dp=lw_lang_string(LW_LANG_STRING_VOLUME_SFX);
+  d[5].dp=lw_lang_string(LW_LANG_STRING_VOLUME_CLICK);
+  d[6].dp=lw_lang_string(LW_LANG_STRING_VOLUME_GAMEWATER);
+  d[7].dp=lw_lang_string(LW_LANG_STRING_VOLUME_MENUWATER);
+  d[8].dp=lw_lang_string(LW_LANG_STRING_VOLUME_MUSIC);
   d[9].dp3=&CONFIG_SFX_VOLUME;
   d[10].dp3=&CONFIG_CLICK_VOLUME;
   d[11].dp3=&CONFIG_WATER_VOLUME_GAME;
   d[12].dp3=&WATER_VOLUME;
   d[13].dp3=&CONFIG_MUSIC_VOLUME;
   for (i=9;i<14;++i)
-      {
-       d[i].d1=16;
-       d[i].dp=NULL;
-       d[i].dp2=slider_int;
-       temp=d[i].dp3;
-       d[i].d2=*temp;
-      }
+    {
+      d[i].d1=16;
+      d[i].dp=NULL;
+      d[i].dp2=slider_int;
+      temp=d[i].dp3;
+      d[i].d2=*temp;
+    }
  
   d[14].proc=0;
 
   while (retour==0)
-        {
-          choix=my_do_dialog (d,choix);
-          switch (choix)
-            {
-             case -1:
-             case MENU_QUICK_BACK:
-                  retour=1;
-                  break;
-             case MENU_QUICK_MAIN:
-                  retour=MENU_TOP;
-                  break;
-             case MENU_QUICK_QUIT:
-                  if (confirm_quit())
-                    retour=MENU_EXIT;
-                  else
-                    display_back_image();
-                  break;
-             case MENU_QUICK_HELP:
-                  retour=display_help (HELP_TEXT_SOUND);
-                  display_back_image ();
-                  break;
-             }
-        }
+    {
+      choix=my_do_dialog (d,choix);
+      switch (choix)
+	{
+	case -1:
+	case MENU_QUICK_BACK:
+	  retour=1;
+	  break;
+	case MENU_QUICK_MAIN:
+	  retour=MENU_TOP;
+	  break;
+	case MENU_QUICK_QUIT:
+	  if (confirm_quit())
+	    retour=MENU_EXIT;
+	  else
+	    display_back_image();
+	  break;
+	case MENU_QUICK_PLAY:
+	  retour=MENU_PLAY;
+	  break;
+	}
+    }
 
   CONFIG_WATER_VOLUME_MENU=WATER_VOLUME;
 
   if (retour>0)
     retour--;
 
- return retour;
+  return retour;
 }
 
 
