@@ -70,37 +70,37 @@ char READABLE_NAME[32];
 /*-----------------------------------------------------------------*/
 void display_common_help(void)
 {
- printf ("liquidwarmap 1.0.0 by U-Foot. (ufoot@bigfoot.com)\n");
- printf ("This program creates maps for Liquid War.\n");
- printf ("It is free software, protected by the GPL.\n");
- printf ("It uses Allegro by Shawn Hargreaves.\n");
- printf ("\n");
+  printf ("liquidwarmap 1.0.0 by U-Foot. (ufoot@bigfoot.com)\n");
+  printf ("This program creates maps for Liquid War.\n");
+  printf ("It is free software, protected by the GPL.\n");
+  printf ("It uses Allegro by Shawn Hargreaves.\n");
+  printf ("\n");
 }
 
 /*-----------------------------------------------------------------*/
 void display_short_help (void)
 {
- display_common_help();
- printf ("Type \"liquidwarmap -?\" for more help.\n");
+  display_common_help();
+  printf ("Type \"liquidwarmap -?\" for more help.\n");
 }
 
 /*-----------------------------------------------------------------*/
 void display_long_help (void)
 {
- display_common_help();
- printf ("The source must be a 256 color bitmap.\n");
- printf ("Color 0=walls, the map must be contained in a closed rectangle.\n");
- printf ("Other colors ignored.\n");
- printf ("\n");
- printf ("Syntax:\n");
- printf ("liquidwarmap [options] filenames\n");
- printf ("\n");
- printf ("Options:\n");
- printf ("-? -h -H : displays this help.\n");
- printf ("-s -S :    silent mode, nothing written to the console.\n");
- printf ("\n");
- printf ("Remark: the created map will have a .map extension.\n");
- printf ("Warning: the source file will be replaced by a smaller file.\n");
+  display_common_help();
+  printf ("The source must be a 256 color bitmap.\n");
+  printf ("Color 0=walls, the map must be contained in a closed rectangle.\n");
+  printf ("Other colors ignored.\n");
+  printf ("\n");
+  printf ("Syntax:\n");
+  printf ("liquidwarmap [options] filenames\n");
+  printf ("\n");
+  printf ("Options:\n");
+  printf ("-? -h -H : displays this help.\n");
+  printf ("-s -S :    silent mode, nothing written to the console.\n");
+  printf ("\n");
+  printf ("Remark: the created map will have a .map extension.\n");
+  printf ("Warning: the source file will be replaced by a smaller file.\n");
 }
 
 /*-----------------------------------------------------------------*/
@@ -110,47 +110,47 @@ void display_long_help (void)
 /*-----------------------------------------------------------------*/
 int acknowledge_flag (char *str)
 {
- int found=0;
+  int found=0;
 
- if (str[0]=='-' || str[0]=='/')
+  if (str[0]=='-' || str[0]=='/')
     {
-     found=1;
-     switch (str[1])
-     {
-      case '?':
-      case 'h':
-      case 'H': FLAG_HELP=1;
-                break;
-      case 's':
-      case 'S': FLAG_SILENT=1;
-                break;
-      default : found=0;
-     }
+      found=1;
+      switch (str[1])
+	{
+	case '?':
+	case 'h':
+	case 'H': FLAG_HELP=1;
+	  break;
+	case 's':
+	case 'S': FLAG_SILENT=1;
+	  break;
+	default : found=0;
+	}
     }
- return found;
+  return found;
 }
 
 /*-----------------------------------------------------------------*/
 int read_command_line (void)
 {
- int      i,j=0,success=1;
+  int      i,j=0,success=1;
 
- for (i=1; i<ARGC; ++i)
-     {
+  for (i=1; i<ARGC; ++i)
+    {
       if ((!acknowledge_flag (ARGV[i])))
-         {
-             FILENAMES[j]=ARGV[i];
+	{
+	  FILENAMES[j]=ARGV[i];
           j++;
-         }
-     }
- NUMBER_OF_FILES=j;
- if (NUMBER_OF_FILES<=0)
-     {
+	}
+    }
+  NUMBER_OF_FILES=j;
+  if (NUMBER_OF_FILES<=0)
+    {
       success=0;
       if (!FLAG_HELP)
-         printf ("ERROR! Two few arguments.\n");
-     }
- return success;
+	printf ("ERROR! Two few arguments.\n");
+    }
+  return success;
 }
 
 /*-----------------------------------------------------------------*/
@@ -160,18 +160,18 @@ int read_command_line (void)
 /*-----------------------------------------------------------------*/
 int load_file (char *filename)
 {
- int success;
+  int success;
 
- if (!FLAG_SILENT)
+  if (!FLAG_SILENT)
     printf ("Loading '%s'.\n", filename);
 
- if (BITMAP_SRC != NULL)
+  if (BITMAP_SRC != NULL)
     destroy_bitmap (BITMAP_SRC);
- BITMAP_SRC=load_bitmap (filename, PALETTE_SRC);
- success=BITMAP_SRC!=NULL;
- if (!success)
+  BITMAP_SRC=load_bitmap (filename, PALETTE_SRC);
+  success=BITMAP_SRC!=NULL;
+  if (!success)
     printf ("ERROR! Unable to read '%s'.\n", filename);
- return success;
+  return success;
 }
 
 /*-----------------------------------------------------------------*/
@@ -181,39 +181,39 @@ int load_file (char *filename)
 /*-----------------------------------------------------------------*/
 void get_range (void)
 {
- int min_x=BITMAP_SRC->w;
- int min_y=BITMAP_SRC->h;
- int max_x=-1;
- int max_y=-1;
- int x,y;
+  int min_x=BITMAP_SRC->w;
+  int min_y=BITMAP_SRC->h;
+  int max_x=-1;
+  int max_y=-1;
+  int x,y;
 
- for (y=0;y<BITMAP_SRC->h;++y)
-     for (x=0;x<BITMAP_SRC->w;++x)
-         if (!getpixel (BITMAP_SRC,x,y))
-            {
-             if (min_x>x)
-                min_x=x;
-             if (min_y>y)
-                min_y=y;
-             if (max_x<x)
-                max_x=x;
-             if (max_y<y)
-                max_y=y;
-            }
- DST_X=min_x;
- DST_Y=min_y;
- DST_W=max_x-min_x+1;
- DST_H=max_y-min_y+1;
+  for (y=0;y<BITMAP_SRC->h;++y)
+    for (x=0;x<BITMAP_SRC->w;++x)
+      if (!getpixel (BITMAP_SRC,x,y))
+	{
+	  if (min_x>x)
+	    min_x=x;
+	  if (min_y>y)
+	    min_y=y;
+	  if (max_x<x)
+	    max_x=x;
+	  if (max_y<y)
+	    max_y=y;
+	}
+  DST_X=min_x;
+  DST_Y=min_y;
+  DST_W=max_x-min_x+1;
+  DST_H=max_y-min_y+1;
 
- if (DST_W<1 || DST_H<1)
+  if (DST_W<1 || DST_H<1)
     {
-     printf ("ERROR! Map is too small.\n");
-     DST_W=DST_H=1;
+      printf ("ERROR! Map is too small.\n");
+      DST_W=DST_H=1;
     }
- if (BITMAP_DST!=NULL)
+  if (BITMAP_DST!=NULL)
     destroy_bitmap (BITMAP_DST);
- BITMAP_DST=create_bitmap (DST_W,DST_H);
- blit (BITMAP_SRC, BITMAP_DST, DST_X, DST_Y, 0, 0, DST_W, DST_H);
+  BITMAP_DST=create_bitmap (DST_W,DST_H);
+  blit (BITMAP_SRC, BITMAP_DST, DST_X, DST_Y, 0, 0, DST_W, DST_H);
 }
 
 /*-----------------------------------------------------------------*/
@@ -223,40 +223,40 @@ void get_range (void)
 /*-----------------------------------------------------------------*/
 void convert_to_buffer (void)
 {
- int pos_src,pos_dst,l,wh;
- char *data;
+  int pos_src,pos_dst,l,wh;
+  char *data;
 
- wh=BITMAP_DST->h*BITMAP_DST->w;
- data=BITMAP_DST->dat;
- pos_src=pos_dst=0;
- BG_SIZE=0;
+  wh=BITMAP_DST->h*BITMAP_DST->w;
+  data=BITMAP_DST->dat;
+  pos_src=pos_dst=0;
+  BG_SIZE=0;
 
- while (pos_src<wh)
-   {
-   l=0;
-   if (!data[pos_src])
-      {
-       while (pos_src<wh && (!data[pos_src]) && l<127)
-         {
-          l++;
-          pos_src++;
-         }
-       BUFFER[pos_dst++]=l;
-      }
-   else
-      {
-       while (pos_src<wh && data[pos_src] && l<127)
-         {
-          l++;
-          pos_src++;
-         }
-       BUFFER[pos_dst++]=-l;
-       BG_SIZE+=l;
-      }
-   }
- BUFFER[pos_dst++]=0;
+  while (pos_src<wh)
+    {
+      l=0;
+      if (!data[pos_src])
+	{
+	  while (pos_src<wh && (!data[pos_src]) && l<127)
+	    {
+	      l++;
+	      pos_src++;
+	    }
+	  BUFFER[pos_dst++]=l;
+	}
+      else
+	{
+	  while (pos_src<wh && data[pos_src] && l<127)
+	    {
+	      l++;
+	      pos_src++;
+	    }
+	  BUFFER[pos_dst++]=-l;
+	  BG_SIZE+=l;
+	}
+    }
+  BUFFER[pos_dst++]=0;
 
- DST_SIZE=pos_dst;
+  DST_SIZE=pos_dst;
 }
 
 /*-----------------------------------------------------------------*/
@@ -333,40 +333,40 @@ void change_ext_to_map (char *str)
 /*-----------------------------------------------------------------*/
 void write_to_disk (char *str)
 {
- FILE *f;
- short w,h;
- int size;
+  FILE *f;
+  short w,h;
+  int size;
 
- if (!FLAG_SILENT)
+  if (!FLAG_SILENT)
     printf ("Writing %s to disk.\n",str);
- delete_file (str);
- f=fopen (str,"w");
- if (f!=NULL)
- {
-    w=DST_W;
-    h=DST_H;
-    size=DST_SIZE;
-    fwrite (&BG_SIZE,4,1,f);
-    fwrite (&w,2,1,f);
-    fwrite (&h,2,1,f);
-    fwrite (READABLE_NAME,sizeof(READABLE_NAME),1,f);
-    fwrite (BUFFER,DST_SIZE,1,f);
-    fclose (f);
- }
- else
- {
-  printf("Unable to write %s.\n",str);
- }
+  delete_file (str);
+  f=fopen (str,"w");
+  if (f!=NULL)
+    {
+      w=DST_W;
+      h=DST_H;
+      size=DST_SIZE;
+      fwrite (&BG_SIZE,4,1,f);
+      fwrite (&w,2,1,f);
+      fwrite (&h,2,1,f);
+      fwrite (READABLE_NAME,sizeof(READABLE_NAME),1,f);
+      fwrite (BUFFER,DST_SIZE,1,f);
+      fclose (f);
+    }
+  else
+    {
+      printf("Unable to write %s.\n",str);
+    }
 }
 
 /*-----------------------------------------------------------------*/
 void write_with_new_size (char *str)
 {
- if (!FLAG_SILENT)
-     printf ("Writing %s to disk.\n",str);
- delete_file (str);
+  if (!FLAG_SILENT)
+    printf ("Writing %s to disk.\n",str);
+  delete_file (str);
 
- save_bitmap (str,BITMAP_DST,PALETTE_SRC);
+  save_bitmap (str,BITMAP_DST,PALETTE_SRC);
 }
 
 /*=================================================================*/
@@ -376,44 +376,47 @@ void write_with_new_size (char *str)
 /*-----------------------------------------------------------------*/
 int main (int argc, char **argv)
 {
- int  i;
+  int  i;
 
- ARGC=argc;
- ARGV=argv;
+  ARGC=argc;
+  ARGV=argv;
 
 #ifdef ALLEGRO_UNIX
- install_allegro(SYSTEM_NONE, &errno, atexit);
+  install_allegro(SYSTEM_NONE, &errno, atexit);
 #else
- allegro_init ();
+  allegro_init ();
 #endif
 
- if (read_command_line ())
+  set_color_depth(8);
+  set_color_conversion(COLORCONV_REDUCE_TO_256);
+
+  if (read_command_line ())
     {
-     for (i=0; i<NUMBER_OF_FILES; ++i)
-         {
+      for (i=0; i<NUMBER_OF_FILES; ++i)
+	{
           if (load_file (FILENAMES [i]))
-             {
+	    {
               get_range ();
 	      if (BITMAP_SRC->w!=BITMAP_DST->w || BITMAP_SRC->h!=BITMAP_DST->h)
-              	  write_with_new_size(FILENAMES [i]);
+		write_with_new_size(FILENAMES [i]);
               convert_to_buffer ();
               change_ext_to_txt (FILENAMES [i]);
 	      update_readable_name(FILENAMES [i]);
               change_ext_to_map (FILENAMES [i]);
               write_to_disk (FILENAMES [i]);
-              }
+	    }
         }
     }
- else
-     {
+  else
+    {
       if (FLAG_HELP)
-         display_long_help ();
+	display_long_help ();
       else
-          display_short_help ();
-     }
- allegro_exit ();
+	display_short_help ();
+    }
+  allegro_exit ();
 
- return 0;
+  return 0;
 
 }
 
@@ -422,7 +425,8 @@ END_OF_MAIN()
 #endif
 
 #ifdef ALLEGRO_UNIX
-END_OF_MAIN();
+     END_OF_MAIN();
 #endif
 
 
+     
