@@ -72,34 +72,34 @@ char  BUFFER[1048576];
 /*-----------------------------------------------------------------*/
 void display_common_help(void)
 {
- printf ("liquidwartex 1.0.0 by U-Foot (ufoot@bigfoot.com).\n");
- printf ("This program creates textures for Liquid War.\n");
- printf ("It is free software, protected by the GPL.\n");
- printf ("It uses Allegro by Shawn Hargreaves.\n");
- printf ("\n");
+  printf ("liquidwartex 1.0.0 by U-Foot (ufoot@bigfoot.com).\n");
+  printf ("This program creates textures for Liquid War.\n");
+  printf ("It is free software, protected by the GPL.\n");
+  printf ("It uses Allegro by Shawn Hargreaves.\n");
+  printf ("\n");
 }
 
 /*-----------------------------------------------------------------*/
 void display_short_help (void)
 {
- display_common_help();
- printf ("Type \"liquidwartex -?\" for more help.\n");
+  display_common_help();
+  printf ("Type \"liquidwartex -?\" for more help.\n");
 }
 
 /*-----------------------------------------------------------------*/
 void display_long_help (void)
 {
- display_common_help();
- printf ("The source must be a 256 color bitmap using color from 32 to 63.\n");
- printf ("\n");
- printf ("Syntax:\n");
- printf ("liquidwartex [options] filenames\n");
- printf ("\n");
- printf ("Options:\n");
- printf ("-? -h -H : displays this help.\n");
- printf ("-s -S :    silent mode, nothing written to the console.\n");
- printf ("\n");
- printf ("Remark: the created texture will have a .tex extension.\n");
+  display_common_help();
+  printf ("The source must be a 256 color bitmap using color from 32 to 63.\n");
+  printf ("\n");
+  printf ("Syntax:\n");
+  printf ("liquidwartex [options] filenames\n");
+  printf ("\n");
+  printf ("Options:\n");
+  printf ("-? -h -H : displays this help.\n");
+  printf ("-s -S :    silent mode, nothing written to the console.\n");
+  printf ("\n");
+  printf ("Remark: the created texture will have a .tex extension.\n");
 }
 
 /*-----------------------------------------------------------------*/
@@ -109,47 +109,47 @@ void display_long_help (void)
 /*-----------------------------------------------------------------*/
 int acknowledge_flag (char *str)
 {
- int found=0;
+  int found=0;
 
- if (str[0]=='-' || str[0]=='/')
+  if (str[0]=='-' || str[0]=='/')
     {
-     found=1;
-     switch (str[1])
-     {
-      case '?':
-      case 'h':
-      case 'H': FLAG_HELP=1;
-                break;
-      case 's':
-      case 'S': FLAG_SILENT=1;
-                break;
-      default : found=0;
-     }
+      found=1;
+      switch (str[1])
+	{
+	case '?':
+	case 'h':
+	case 'H': FLAG_HELP=1;
+	  break;
+	case 's':
+	case 'S': FLAG_SILENT=1;
+	  break;
+	default : found=0;
+	}
     }
- return found;
+  return found;
 }
 
 /*-----------------------------------------------------------------*/
 int read_command_line (void)
 {
- int      i,j=0,success=1;
+  int      i,j=0,success=1;
 
- for (i=1; i<ARGC; ++i)
-     {
+  for (i=1; i<ARGC; ++i)
+    {
       if ((!acknowledge_flag (ARGV[i])))
-         {
-             FILENAMES[j]=ARGV[i];
+	{
+	  FILENAMES[j]=ARGV[i];
           j++;
-         }
-     }
- NUMBER_OF_FILES=j;
- if (NUMBER_OF_FILES<=0)
-     {
+	}
+    }
+  NUMBER_OF_FILES=j;
+  if (NUMBER_OF_FILES<=0)
+    {
       success=0;
       if (!FLAG_HELP)
-         printf ("ERROR! Two few arguments.\n");
-     }
- return success;
+	printf ("ERROR! Two few arguments.\n");
+    }
+  return success;
 }
 
 /*-----------------------------------------------------------------*/
@@ -159,18 +159,18 @@ int read_command_line (void)
 /*-----------------------------------------------------------------*/
 int load_file (char *filename)
 {
- int success;
+  int success;
 
- if (!FLAG_SILENT)
+  if (!FLAG_SILENT)
     printf ("Loading '%s'.\n", filename);
 
- if (BITMAP_SRC != NULL)
+  if (BITMAP_SRC != NULL)
     destroy_bitmap (BITMAP_SRC);
- BITMAP_SRC=load_bitmap (filename, PALETTE_SRC);
- success=BITMAP_SRC!=NULL;
- if (!success)
+  BITMAP_SRC=load_bitmap (filename, PALETTE_SRC);
+  success=BITMAP_SRC!=NULL;
+  if (!success)
     printf ("ERROR! Unable to read '%s'.\n", filename);
- return success;
+  return success;
 }
 
 /*-----------------------------------------------------------------*/
@@ -180,37 +180,37 @@ int load_file (char *filename)
 /*-----------------------------------------------------------------*/
 void get_range (void)
 {
- int min_x=BITMAP_SRC->w;
- int min_y=BITMAP_SRC->h;
- int max_x=-1;
- int max_y=-1;
- int x,y;
+  int min_x=BITMAP_SRC->w;
+  int min_y=BITMAP_SRC->h;
+  int max_x=-1;
+  int max_y=-1;
+  int x,y;
 
- for (y=0;y<BITMAP_SRC->h;++y)
-     for (x=0;x<BITMAP_SRC->w;++x)
-         if (getpixel (BITMAP_SRC,x,y)>=FIRST_COLOR ||
-             getpixel (BITMAP_SRC,x,y)<FIRST_COLOR+COLOR_NUMBER)
-            {
-             if (min_x>x)
-                min_x=x;
-             if (min_y>y)
-                min_y=y;
-             if (max_x<x)
-                max_x=x;
-             if (max_y<y)
-                max_y=y;
-            }
- DST_X=min_x;
- DST_Y=min_y;
- DST_W=max_x-min_x+1;
- DST_H=max_y-min_y+1;
+  for (y=0;y<BITMAP_SRC->h;++y)
+    for (x=0;x<BITMAP_SRC->w;++x)
+      if (getpixel (BITMAP_SRC,x,y)>=FIRST_COLOR ||
+	  getpixel (BITMAP_SRC,x,y)<FIRST_COLOR+COLOR_NUMBER)
+	{
+	  if (min_x>x)
+	    min_x=x;
+	  if (min_y>y)
+	    min_y=y;
+	  if (max_x<x)
+	    max_x=x;
+	  if (max_y<y)
+	    max_y=y;
+	}
+  DST_X=min_x;
+  DST_Y=min_y;
+  DST_W=max_x-min_x+1;
+  DST_H=max_y-min_y+1;
 
- if (DST_W<1 || DST_H<1)
+  if (DST_W<1 || DST_H<1)
     {
-     printf ("ERROR! Texture is too small.\n");
-     DST_W=DST_H=1;
+      printf ("ERROR! Texture is too small.\n");
+      DST_W=DST_H=1;
     }
- DST_SIZE=3*COLOR_NUMBER+((DST_W*DST_H+7)/8)*5;
+  DST_SIZE=3*COLOR_NUMBER+((DST_W*DST_H+7)/8)*5;
 }
 
 /*-----------------------------------------------------------------*/
@@ -220,43 +220,43 @@ void get_range (void)
 /*-----------------------------------------------------------------*/
 void convert_to_buffer (void)
 {
- int pos=0,pos8=0,x,y,i;
- char octet[5],toadd;
- int   coul;
+  int pos=0,pos8=0,x,y,i;
+  char octet[5],toadd;
+  int   coul;
 
- for (i=0;i<COLOR_NUMBER;++i)
-     {
+  for (i=0;i<COLOR_NUMBER;++i)
+    {
       BUFFER[pos++]=PALETTE_SRC[FIRST_COLOR+i].r;
       BUFFER[pos++]=PALETTE_SRC[FIRST_COLOR+i].g;
       BUFFER[pos++]=PALETTE_SRC[FIRST_COLOR+i].b;
-     }
+    }
 
- for (i=0;i<5;++i)
-     octet[i]=0;
+  for (i=0;i<5;++i)
+    octet[i]=0;
 
- for (y=0;y<DST_H;++y)
-     for (x=0;x<DST_W;++x)
-         {
-          coul=getpixel (BITMAP_SRC,DST_X+x,DST_Y+y)-FIRST_COLOR;
-          toadd=1<<pos8;
-          octet[0]|=(coul&1) ? toadd : 0;
-          octet[1]|=(coul&2) ? toadd : 0;
-          octet[2]|=(coul&4) ? toadd : 0;
-          octet[3]|=(coul&8) ? toadd : 0;
-          octet[4]|=(coul&16) ? toadd : 0;
+  for (y=0;y<DST_H;++y)
+    for (x=0;x<DST_W;++x)
+      {
+	coul=getpixel (BITMAP_SRC,DST_X+x,DST_Y+y)-FIRST_COLOR;
+	toadd=1<<pos8;
+	octet[0]|=(coul&1) ? toadd : 0;
+	octet[1]|=(coul&2) ? toadd : 0;
+	octet[2]|=(coul&4) ? toadd : 0;
+	octet[3]|=(coul&8) ? toadd : 0;
+	octet[4]|=(coul&16) ? toadd : 0;
 
-          if (pos8==7 || (y==DST_H-1 && x==DST_W-1))
-             {
-              for (i=0;i<5;++i)
-                  {
-                   BUFFER[pos++]=octet[i];
-                   octet[i]=0;
-                  }
-              pos8=0;
-             }
-          else
-              pos8++;
-          }
+	if (pos8==7 || (y==DST_H-1 && x==DST_W-1))
+	  {
+	    for (i=0;i<5;++i)
+	      {
+		BUFFER[pos++]=octet[i];
+		octet[i]=0;
+	      }
+	    pos8=0;
+	  }
+	else
+	  pos8++;
+      }
 }
 
 /*-----------------------------------------------------------------*/
@@ -277,26 +277,26 @@ void change_ext (char *str)
 /*-----------------------------------------------------------------*/
 void write_to_disk (char *str)
 {
- FILE *f;
- short w,h;
+  FILE *f;
+  short w,h;
 
- if (!FLAG_SILENT)
-   printf ("Writing %s to disk.\n",str);
- delete_file (str);
- f=fopen (str,"w");
- if (f!=NULL)
- {
-    w=DST_W;
-    h=DST_H;
-    fwrite (&w,2,1,f);
-    fwrite (&h,2,1,f);
-    fwrite (BUFFER,DST_SIZE,1,f);
-    fclose (f);
- }
- else
- {
-   printf("Unable to write %s.\n",str);
- }
+  if (!FLAG_SILENT)
+    printf ("Writing %s to disk.\n",str);
+  delete_file (str);
+  f=fopen (str,"w");
+  if (f!=NULL)
+    {
+      w=DST_W;
+      h=DST_H;
+      fwrite (&w,2,1,f);
+      fwrite (&h,2,1,f);
+      fwrite (BUFFER,DST_SIZE,1,f);
+      fclose (f);
+    }
+  else
+    {
+      printf("Unable to write %s.\n",str);
+    }
 }
 
 /*=================================================================*/
@@ -306,40 +306,43 @@ void write_to_disk (char *str)
 /*-----------------------------------------------------------------*/
 int main (int argc, char **argv)
 {
- int  i;
+  int  i;
 
- ARGC=argc;
- ARGV=argv;
+  ARGC=argc;
+  ARGV=argv;
 
 #ifdef ALLEGRO_UNIX
- install_allegro(SYSTEM_NONE, &errno, atexit);
+  install_allegro(SYSTEM_NONE, &errno, atexit);
 #else
- allegro_init ();
+  allegro_init ();
 #endif
 
- if (read_command_line ())
+  set_color_depth(8);
+  set_color_conversion(COLORCONV_REDUCE_TO_256);
+
+  if (read_command_line ())
     {
-     for (i=0; i<NUMBER_OF_FILES; ++i)
-         {
+      for (i=0; i<NUMBER_OF_FILES; ++i)
+	{
           if (load_file (FILENAMES [i]))
-             {
+	    {
               get_range ();
               convert_to_buffer ();
               change_ext (FILENAMES [i]);
               write_to_disk (FILENAMES [i]);
-              }
+	    }
         }
     }
- else
-     {
+  else
+    {
       if (FLAG_HELP)
-         display_long_help ();
+	display_long_help ();
       else
-          display_short_help ();
-     }
- allegro_exit ();
+	display_short_help ();
+    }
+  allegro_exit ();
 
- return 0;
+  return 0;
 
 }
 
@@ -348,7 +351,8 @@ END_OF_MAIN()
 #endif
 
 #ifdef ALLEGRO_UNIX
-END_OF_MAIN();
+     END_OF_MAIN();
 #endif
 
 
+     
